# generated from /usr/local/include/gtk-2.0/gdk/gdkkeysyms.h
package Gtk2::Gdk::Keysyms;
%Gtk2::Gdk::Keysyms = (
   'VoidSymbol' => 0xffffff,
   'BackSpace' => 0xff08,
   'Tab' => 0xff09,
   'Linefeed' => 0xff0a,
   'Clear' => 0xff0b,
   'Return' => 0xff0d,
   'Pause' => 0xff13,
   'Scroll_Lock' => 0xff14,
   'Sys_Req' => 0xff15,
   'Escape' => 0xff1b,
   'Delete' => 0xffff,
   'Multi_key' => 0xff20,
   'Codeinput' => 0xff37,
   'SingleCandidate' => 0xff3c,
   'MultipleCandidate' => 0xff3d,
   'PreviousCandidate' => 0xff3e,
   'Kanji' => 0xff21,
   'Muhenkan' => 0xff22,
   'Henkan_Mode' => 0xff23,
   'Henkan' => 0xff23,
   'Romaji' => 0xff24,
   'Hiragana' => 0xff25,
   'Katakana' => 0xff26,
   'Hiragana_Katakana' => 0xff27,
   'Zenkaku' => 0xff28,
   'Hankaku' => 0xff29,
   'Zenkaku_Hankaku' => 0xff2a,
   'Touroku' => 0xff2b,
   'Massyo' => 0xff2c,
   'Kana_Lock' => 0xff2d,
   'Kana_Shift' => 0xff2e,
   'Eisu_Shift' => 0xff2f,
   'Eisu_toggle' => 0xff30,
   'Kanji_Bangou' => 0xff37,
   'Zen_Koho' => 0xff3d,
   'Mae_Koho' => 0xff3e,
   'Home' => 0xff50,
   'Left' => 0xff51,
   'Up' => 0xff52,
   'Right' => 0xff53,
   'Down' => 0xff54,
   'Prior' => 0xff55,
   'Page_Up' => 0xff55,
   'Next' => 0xff56,
   'Page_Down' => 0xff56,
   'End' => 0xff57,
   'Begin' => 0xff58,
   'Select' => 0xff60,
   'Print' => 0xff61,
   'Execute' => 0xff62,
   'Insert' => 0xff63,
   'Undo' => 0xff65,
   'Redo' => 0xff66,
   'Menu' => 0xff67,
   'Find' => 0xff68,
   'Cancel' => 0xff69,
   'Help' => 0xff6a,
   'Break' => 0xff6b,
   'Mode_switch' => 0xff7e,
   'script_switch' => 0xff7e,
   'Num_Lock' => 0xff7f,
   'KP_Space' => 0xff80,
   'KP_Tab' => 0xff89,
   'KP_Enter' => 0xff8d,
   'KP_F1' => 0xff91,
   'KP_F2' => 0xff92,
   'KP_F3' => 0xff93,
   'KP_F4' => 0xff94,
   'KP_Home' => 0xff95,
   'KP_Left' => 0xff96,
   'KP_Up' => 0xff97,
   'KP_Right' => 0xff98,
   'KP_Down' => 0xff99,
   'KP_Prior' => 0xff9a,
   'KP_Page_Up' => 0xff9a,
   'KP_Next' => 0xff9b,
   'KP_Page_Down' => 0xff9b,
   'KP_End' => 0xff9c,
   'KP_Begin' => 0xff9d,
   'KP_Insert' => 0xff9e,
   'KP_Delete' => 0xff9f,
   'KP_Equal' => 0xffbd,
   'KP_Multiply' => 0xffaa,
   'KP_Add' => 0xffab,
   'KP_Separator' => 0xffac,
   'KP_Subtract' => 0xffad,
   'KP_Decimal' => 0xffae,
   'KP_Divide' => 0xffaf,
   'KP_0' => 0xffb0,
   'KP_1' => 0xffb1,
   'KP_2' => 0xffb2,
   'KP_3' => 0xffb3,
   'KP_4' => 0xffb4,
   'KP_5' => 0xffb5,
   'KP_6' => 0xffb6,
   'KP_7' => 0xffb7,
   'KP_8' => 0xffb8,
   'KP_9' => 0xffb9,
   'F1' => 0xffbe,
   'F2' => 0xffbf,
   'F3' => 0xffc0,
   'F4' => 0xffc1,
   'F5' => 0xffc2,
   'F6' => 0xffc3,
   'F7' => 0xffc4,
   'F8' => 0xffc5,
   'F9' => 0xffc6,
   'F10' => 0xffc7,
   'F11' => 0xffc8,
   'L1' => 0xffc8,
   'F12' => 0xffc9,
   'L2' => 0xffc9,
   'F13' => 0xffca,
   'L3' => 0xffca,
   'F14' => 0xffcb,
   'L4' => 0xffcb,
   'F15' => 0xffcc,
   'L5' => 0xffcc,
   'F16' => 0xffcd,
   'L6' => 0xffcd,
   'F17' => 0xffce,
   'L7' => 0xffce,
   'F18' => 0xffcf,
   'L8' => 0xffcf,
   'F19' => 0xffd0,
   'L9' => 0xffd0,
   'F20' => 0xffd1,
   'L10' => 0xffd1,
   'F21' => 0xffd2,
   'R1' => 0xffd2,
   'F22' => 0xffd3,
   'R2' => 0xffd3,
   'F23' => 0xffd4,
   'R3' => 0xffd4,
   'F24' => 0xffd5,
   'R4' => 0xffd5,
   'F25' => 0xffd6,
   'R5' => 0xffd6,
   'F26' => 0xffd7,
   'R6' => 0xffd7,
   'F27' => 0xffd8,
   'R7' => 0xffd8,
   'F28' => 0xffd9,
   'R8' => 0xffd9,
   'F29' => 0xffda,
   'R9' => 0xffda,
   'F30' => 0xffdb,
   'R10' => 0xffdb,
   'F31' => 0xffdc,
   'R11' => 0xffdc,
   'F32' => 0xffdd,
   'R12' => 0xffdd,
   'F33' => 0xffde,
   'R13' => 0xffde,
   'F34' => 0xffdf,
   'R14' => 0xffdf,
   'F35' => 0xffe0,
   'R15' => 0xffe0,
   'Shift_L' => 0xffe1,
   'Shift_R' => 0xffe2,
   'Control_L' => 0xffe3,
   'Control_R' => 0xffe4,
   'Caps_Lock' => 0xffe5,
   'Shift_Lock' => 0xffe6,
   'Meta_L' => 0xffe7,
   'Meta_R' => 0xffe8,
   'Alt_L' => 0xffe9,
   'Alt_R' => 0xffea,
   'Super_L' => 0xffeb,
   'Super_R' => 0xffec,
   'Hyper_L' => 0xffed,
   'Hyper_R' => 0xffee,
   'ISO_Lock' => 0xfe01,
   'ISO_Level2_Latch' => 0xfe02,
   'ISO_Level3_Shift' => 0xfe03,
   'ISO_Level3_Latch' => 0xfe04,
   'ISO_Level3_Lock' => 0xfe05,
   'ISO_Level5_Shift' => 0xfe11,
   'ISO_Level5_Latch' => 0xfe12,
   'ISO_Level5_Lock' => 0xfe13,
   'ISO_Group_Shift' => 0xff7e,
   'ISO_Group_Latch' => 0xfe06,
   'ISO_Group_Lock' => 0xfe07,
   'ISO_Next_Group' => 0xfe08,
   'ISO_Next_Group_Lock' => 0xfe09,
   'ISO_Prev_Group' => 0xfe0a,
   'ISO_Prev_Group_Lock' => 0xfe0b,
   'ISO_First_Group' => 0xfe0c,
   'ISO_First_Group_Lock' => 0xfe0d,
   'ISO_Last_Group' => 0xfe0e,
   'ISO_Last_Group_Lock' => 0xfe0f,
   'ISO_Left_Tab' => 0xfe20,
   'ISO_Move_Line_Up' => 0xfe21,
   'ISO_Move_Line_Down' => 0xfe22,
   'ISO_Partial_Line_Up' => 0xfe23,
   'ISO_Partial_Line_Down' => 0xfe24,
   'ISO_Partial_Space_Left' => 0xfe25,
   'ISO_Partial_Space_Right' => 0xfe26,
   'ISO_Set_Margin_Left' => 0xfe27,
   'ISO_Set_Margin_Right' => 0xfe28,
   'ISO_Release_Margin_Left' => 0xfe29,
   'ISO_Release_Margin_Right' => 0xfe2a,
   'ISO_Release_Both_Margins' => 0xfe2b,
   'ISO_Fast_Cursor_Left' => 0xfe2c,
   'ISO_Fast_Cursor_Right' => 0xfe2d,
   'ISO_Fast_Cursor_Up' => 0xfe2e,
   'ISO_Fast_Cursor_Down' => 0xfe2f,
   'ISO_Continuous_Underline' => 0xfe30,
   'ISO_Discontinuous_Underline' => 0xfe31,
   'ISO_Emphasize' => 0xfe32,
   'ISO_Center_Object' => 0xfe33,
   'ISO_Enter' => 0xfe34,
   'dead_grave' => 0xfe50,
   'dead_acute' => 0xfe51,
   'dead_circumflex' => 0xfe52,
   'dead_tilde' => 0xfe53,
   'dead_perispomeni' => 0xfe53,
   'dead_macron' => 0xfe54,
   'dead_breve' => 0xfe55,
   'dead_abovedot' => 0xfe56,
   'dead_diaeresis' => 0xfe57,
   'dead_abovering' => 0xfe58,
   'dead_doubleacute' => 0xfe59,
   'dead_caron' => 0xfe5a,
   'dead_cedilla' => 0xfe5b,
   'dead_ogonek' => 0xfe5c,
   'dead_iota' => 0xfe5d,
   'dead_voiced_sound' => 0xfe5e,
   'dead_semivoiced_sound' => 0xfe5f,
   'dead_belowdot' => 0xfe60,
   'dead_hook' => 0xfe61,
   'dead_horn' => 0xfe62,
   'dead_stroke' => 0xfe63,
   'dead_abovecomma' => 0xfe64,
   'dead_psili' => 0xfe64,
   'dead_abovereversedcomma' => 0xfe65,
   'dead_dasia' => 0xfe65,
   'dead_doublegrave' => 0xfe66,
   'dead_belowring' => 0xfe67,
   'dead_belowmacron' => 0xfe68,
   'dead_belowcircumflex' => 0xfe69,
   'dead_belowtilde' => 0xfe6a,
   'dead_belowbreve' => 0xfe6b,
   'dead_belowdiaeresis' => 0xfe6c,
   'dead_invertedbreve' => 0xfe6d,
   'dead_belowcomma' => 0xfe6e,
   'dead_currency' => 0xfe6f,
   'dead_a' => 0xfe80,
   'dead_A' => 0xfe81,
   'dead_e' => 0xfe82,
   'dead_E' => 0xfe83,
   'dead_i' => 0xfe84,
   'dead_I' => 0xfe85,
   'dead_o' => 0xfe86,
   'dead_O' => 0xfe87,
   'dead_u' => 0xfe88,
   'dead_U' => 0xfe89,
   'dead_small_schwa' => 0xfe8a,
   'dead_capital_schwa' => 0xfe8b,
   'First_Virtual_Screen' => 0xfed0,
   'Prev_Virtual_Screen' => 0xfed1,
   'Next_Virtual_Screen' => 0xfed2,
   'Last_Virtual_Screen' => 0xfed4,
   'Terminate_Server' => 0xfed5,
   'AccessX_Enable' => 0xfe70,
   'AccessX_Feedback_Enable' => 0xfe71,
   'RepeatKeys_Enable' => 0xfe72,
   'SlowKeys_Enable' => 0xfe73,
   'BounceKeys_Enable' => 0xfe74,
   'StickyKeys_Enable' => 0xfe75,
   'MouseKeys_Enable' => 0xfe76,
   'MouseKeys_Accel_Enable' => 0xfe77,
   'Overlay1_Enable' => 0xfe78,
   'Overlay2_Enable' => 0xfe79,
   'AudibleBell_Enable' => 0xfe7a,
   'Pointer_Left' => 0xfee0,
   'Pointer_Right' => 0xfee1,
   'Pointer_Up' => 0xfee2,
   'Pointer_Down' => 0xfee3,
   'Pointer_UpLeft' => 0xfee4,
   'Pointer_UpRight' => 0xfee5,
   'Pointer_DownLeft' => 0xfee6,
   'Pointer_DownRight' => 0xfee7,
   'Pointer_Button_Dflt' => 0xfee8,
   'Pointer_Button1' => 0xfee9,
   'Pointer_Button2' => 0xfeea,
   'Pointer_Button3' => 0xfeeb,
   'Pointer_Button4' => 0xfeec,
   'Pointer_Button5' => 0xfeed,
   'Pointer_DblClick_Dflt' => 0xfeee,
   'Pointer_DblClick1' => 0xfeef,
   'Pointer_DblClick2' => 0xfef0,
   'Pointer_DblClick3' => 0xfef1,
   'Pointer_DblClick4' => 0xfef2,
   'Pointer_DblClick5' => 0xfef3,
   'Pointer_Drag_Dflt' => 0xfef4,
   'Pointer_Drag1' => 0xfef5,
   'Pointer_Drag2' => 0xfef6,
   'Pointer_Drag3' => 0xfef7,
   'Pointer_Drag4' => 0xfef8,
   'Pointer_Drag5' => 0xfefd,
   'Pointer_EnableKeys' => 0xfef9,
   'Pointer_Accelerate' => 0xfefa,
   'Pointer_DfltBtnNext' => 0xfefb,
   'Pointer_DfltBtnPrev' => 0xfefc,
   '3270_Duplicate' => 0xfd01,
   '3270_FieldMark' => 0xfd02,
   '3270_Right2' => 0xfd03,
   '3270_Left2' => 0xfd04,
   '3270_BackTab' => 0xfd05,
   '3270_EraseEOF' => 0xfd06,
   '3270_EraseInput' => 0xfd07,
   '3270_Reset' => 0xfd08,
   '3270_Quit' => 0xfd09,
   '3270_PA1' => 0xfd0a,
   '3270_PA2' => 0xfd0b,
   '3270_PA3' => 0xfd0c,
   '3270_Test' => 0xfd0d,
   '3270_Attn' => 0xfd0e,
   '3270_CursorBlink' => 0xfd0f,
   '3270_AltCursor' => 0xfd10,
   '3270_KeyClick' => 0xfd11,
   '3270_Jump' => 0xfd12,
   '3270_Ident' => 0xfd13,
   '3270_Rule' => 0xfd14,
   '3270_Copy' => 0xfd15,
   '3270_Play' => 0xfd16,
   '3270_Setup' => 0xfd17,
   '3270_Record' => 0xfd18,
   '3270_ChangeScreen' => 0xfd19,
   '3270_DeleteWord' => 0xfd1a,
   '3270_ExSelect' => 0xfd1b,
   '3270_CursorSelect' => 0xfd1c,
   '3270_PrintScreen' => 0xfd1d,
   '3270_Enter' => 0xfd1e,
   'space' => 0x020,
   'exclam' => 0x021,
   'quotedbl' => 0x022,
   'numbersign' => 0x023,
   'dollar' => 0x024,
   'percent' => 0x025,
   'ampersand' => 0x026,
   'apostrophe' => 0x027,
   'quoteright' => 0x027,
   'parenleft' => 0x028,
   'parenright' => 0x029,
   'asterisk' => 0x02a,
   'plus' => 0x02b,
   'comma' => 0x02c,
   'minus' => 0x02d,
   'period' => 0x02e,
   'slash' => 0x02f,
   '0' => 0x030,
   '1' => 0x031,
   '2' => 0x032,
   '3' => 0x033,
   '4' => 0x034,
   '5' => 0x035,
   '6' => 0x036,
   '7' => 0x037,
   '8' => 0x038,
   '9' => 0x039,
   'colon' => 0x03a,
   'semicolon' => 0x03b,
   'less' => 0x03c,
   'equal' => 0x03d,
   'greater' => 0x03e,
   'question' => 0x03f,
   'at' => 0x040,
   'A' => 0x041,
   'B' => 0x042,
   'C' => 0x043,
   'D' => 0x044,
   'E' => 0x045,
   'F' => 0x046,
   'G' => 0x047,
   'H' => 0x048,
   'I' => 0x049,
   'J' => 0x04a,
   'K' => 0x04b,
   'L' => 0x04c,
   'M' => 0x04d,
   'N' => 0x04e,
   'O' => 0x04f,
   'P' => 0x050,
   'Q' => 0x051,
   'R' => 0x052,
   'S' => 0x053,
   'T' => 0x054,
   'U' => 0x055,
   'V' => 0x056,
   'W' => 0x057,
   'X' => 0x058,
   'Y' => 0x059,
   'Z' => 0x05a,
   'bracketleft' => 0x05b,
   'backslash' => 0x05c,
   'bracketright' => 0x05d,
   'asciicircum' => 0x05e,
   'underscore' => 0x05f,
   'grave' => 0x060,
   'quoteleft' => 0x060,
   'a' => 0x061,
   'b' => 0x062,
   'c' => 0x063,
   'd' => 0x064,
   'e' => 0x065,
   'f' => 0x066,
   'g' => 0x067,
   'h' => 0x068,
   'i' => 0x069,
   'j' => 0x06a,
   'k' => 0x06b,
   'l' => 0x06c,
   'm' => 0x06d,
   'n' => 0x06e,
   'o' => 0x06f,
   'p' => 0x070,
   'q' => 0x071,
   'r' => 0x072,
   's' => 0x073,
   't' => 0x074,
   'u' => 0x075,
   'v' => 0x076,
   'w' => 0x077,
   'x' => 0x078,
   'y' => 0x079,
   'z' => 0x07a,
   'braceleft' => 0x07b,
   'bar' => 0x07c,
   'braceright' => 0x07d,
   'asciitilde' => 0x07e,
   'nobreakspace' => 0x0a0,
   'exclamdown' => 0x0a1,
   'cent' => 0x0a2,
   'sterling' => 0x0a3,
   'currency' => 0x0a4,
   'yen' => 0x0a5,
   'brokenbar' => 0x0a6,
   'section' => 0x0a7,
   'diaeresis' => 0x0a8,
   'copyright' => 0x0a9,
   'ordfeminine' => 0x0aa,
   'guillemotleft' => 0x0ab,
   'notsign' => 0x0ac,
   'hyphen' => 0x0ad,
   'registered' => 0x0ae,
   'macron' => 0x0af,
   'degree' => 0x0b0,
   'plusminus' => 0x0b1,
   'twosuperior' => 0x0b2,
   'threesuperior' => 0x0b3,
   'acute' => 0x0b4,
   'mu' => 0x0b5,
   'paragraph' => 0x0b6,
   'periodcentered' => 0x0b7,
   'cedilla' => 0x0b8,
   'onesuperior' => 0x0b9,
   'masculine' => 0x0ba,
   'guillemotright' => 0x0bb,
   'onequarter' => 0x0bc,
   'onehalf' => 0x0bd,
   'threequarters' => 0x0be,
   'questiondown' => 0x0bf,
   'Agrave' => 0x0c0,
   'Aacute' => 0x0c1,
   'Acircumflex' => 0x0c2,
   'Atilde' => 0x0c3,
   'Adiaeresis' => 0x0c4,
   'Aring' => 0x0c5,
   'AE' => 0x0c6,
   'Ccedilla' => 0x0c7,
   'Egrave' => 0x0c8,
   'Eacute' => 0x0c9,
   'Ecircumflex' => 0x0ca,
   'Ediaeresis' => 0x0cb,
   'Igrave' => 0x0cc,
   'Iacute' => 0x0cd,
   'Icircumflex' => 0x0ce,
   'Idiaeresis' => 0x0cf,
   'ETH' => 0x0d0,
   'Eth' => 0x0d0,
   'Ntilde' => 0x0d1,
   'Ograve' => 0x0d2,
   'Oacute' => 0x0d3,
   'Ocircumflex' => 0x0d4,
   'Otilde' => 0x0d5,
   'Odiaeresis' => 0x0d6,
   'multiply' => 0x0d7,
   'Oslash' => 0x0d8,
   'Ooblique' => 0x0d8,
   'Ugrave' => 0x0d9,
   'Uacute' => 0x0da,
   'Ucircumflex' => 0x0db,
   'Udiaeresis' => 0x0dc,
   'Yacute' => 0x0dd,
   'THORN' => 0x0de,
   'Thorn' => 0x0de,
   'ssharp' => 0x0df,
   'agrave' => 0x0e0,
   'aacute' => 0x0e1,
   'acircumflex' => 0x0e2,
   'atilde' => 0x0e3,
   'adiaeresis' => 0x0e4,
   'aring' => 0x0e5,
   'ae' => 0x0e6,
   'ccedilla' => 0x0e7,
   'egrave' => 0x0e8,
   'eacute' => 0x0e9,
   'ecircumflex' => 0x0ea,
   'ediaeresis' => 0x0eb,
   'igrave' => 0x0ec,
   'iacute' => 0x0ed,
   'icircumflex' => 0x0ee,
   'idiaeresis' => 0x0ef,
   'eth' => 0x0f0,
   'ntilde' => 0x0f1,
   'ograve' => 0x0f2,
   'oacute' => 0x0f3,
   'ocircumflex' => 0x0f4,
   'otilde' => 0x0f5,
   'odiaeresis' => 0x0f6,
   'division' => 0x0f7,
   'oslash' => 0x0f8,
   'ooblique' => 0x0f8,
   'ugrave' => 0x0f9,
   'uacute' => 0x0fa,
   'ucircumflex' => 0x0fb,
   'udiaeresis' => 0x0fc,
   'yacute' => 0x0fd,
   'thorn' => 0x0fe,
   'ydiaeresis' => 0x0ff,
   'Aogonek' => 0x1a1,
   'breve' => 0x1a2,
   'Lstroke' => 0x1a3,
   'Lcaron' => 0x1a5,
   'Sacute' => 0x1a6,
   'Scaron' => 0x1a9,
   'Scedilla' => 0x1aa,
   'Tcaron' => 0x1ab,
   'Zacute' => 0x1ac,
   'Zcaron' => 0x1ae,
   'Zabovedot' => 0x1af,
   'aogonek' => 0x1b1,
   'ogonek' => 0x1b2,
   'lstroke' => 0x1b3,
   'lcaron' => 0x1b5,
   'sacute' => 0x1b6,
   'caron' => 0x1b7,
   'scaron' => 0x1b9,
   'scedilla' => 0x1ba,
   'tcaron' => 0x1bb,
   'zacute' => 0x1bc,
   'doubleacute' => 0x1bd,
   'zcaron' => 0x1be,
   'zabovedot' => 0x1bf,
   'Racute' => 0x1c0,
   'Abreve' => 0x1c3,
   'Lacute' => 0x1c5,
   'Cacute' => 0x1c6,
   'Ccaron' => 0x1c8,
   'Eogonek' => 0x1ca,
   'Ecaron' => 0x1cc,
   'Dcaron' => 0x1cf,
   'Dstroke' => 0x1d0,
   'Nacute' => 0x1d1,
   'Ncaron' => 0x1d2,
   'Odoubleacute' => 0x1d5,
   'Rcaron' => 0x1d8,
   'Uring' => 0x1d9,
   'Udoubleacute' => 0x1db,
   'Tcedilla' => 0x1de,
   'racute' => 0x1e0,
   'abreve' => 0x1e3,
   'lacute' => 0x1e5,
   'cacute' => 0x1e6,
   'ccaron' => 0x1e8,
   'eogonek' => 0x1ea,
   'ecaron' => 0x1ec,
   'dcaron' => 0x1ef,
   'dstroke' => 0x1f0,
   'nacute' => 0x1f1,
   'ncaron' => 0x1f2,
   'odoubleacute' => 0x1f5,
   'udoubleacute' => 0x1fb,
   'rcaron' => 0x1f8,
   'uring' => 0x1f9,
   'tcedilla' => 0x1fe,
   'abovedot' => 0x1ff,
   'Hstroke' => 0x2a1,
   'Hcircumflex' => 0x2a6,
   'Iabovedot' => 0x2a9,
   'Gbreve' => 0x2ab,
   'Jcircumflex' => 0x2ac,
   'hstroke' => 0x2b1,
   'hcircumflex' => 0x2b6,
   'idotless' => 0x2b9,
   'gbreve' => 0x2bb,
   'jcircumflex' => 0x2bc,
   'Cabovedot' => 0x2c5,
   'Ccircumflex' => 0x2c6,
   'Gabovedot' => 0x2d5,
   'Gcircumflex' => 0x2d8,
   'Ubreve' => 0x2dd,
   'Scircumflex' => 0x2de,
   'cabovedot' => 0x2e5,
   'ccircumflex' => 0x2e6,
   'gabovedot' => 0x2f5,
   'gcircumflex' => 0x2f8,
   'ubreve' => 0x2fd,
   'scircumflex' => 0x2fe,
   'kra' => 0x3a2,
   'kappa' => 0x3a2,
   'Rcedilla' => 0x3a3,
   'Itilde' => 0x3a5,
   'Lcedilla' => 0x3a6,
   'Emacron' => 0x3aa,
   'Gcedilla' => 0x3ab,
   'Tslash' => 0x3ac,
   'rcedilla' => 0x3b3,
   'itilde' => 0x3b5,
   'lcedilla' => 0x3b6,
   'emacron' => 0x3ba,
   'gcedilla' => 0x3bb,
   'tslash' => 0x3bc,
   'ENG' => 0x3bd,
   'eng' => 0x3bf,
   'Amacron' => 0x3c0,
   'Iogonek' => 0x3c7,
   'Eabovedot' => 0x3cc,
   'Imacron' => 0x3cf,
   'Ncedilla' => 0x3d1,
   'Omacron' => 0x3d2,
   'Kcedilla' => 0x3d3,
   'Uogonek' => 0x3d9,
   'Utilde' => 0x3dd,
   'Umacron' => 0x3de,
   'amacron' => 0x3e0,
   'iogonek' => 0x3e7,
   'eabovedot' => 0x3ec,
   'imacron' => 0x3ef,
   'ncedilla' => 0x3f1,
   'omacron' => 0x3f2,
   'kcedilla' => 0x3f3,
   'uogonek' => 0x3f9,
   'utilde' => 0x3fd,
   'umacron' => 0x3fe,
   'Babovedot' => 0x1001e02,
   'babovedot' => 0x1001e03,
   'Dabovedot' => 0x1001e0a,
   'Wgrave' => 0x1001e80,
   'Wacute' => 0x1001e82,
   'dabovedot' => 0x1001e0b,
   'Ygrave' => 0x1001ef2,
   'Fabovedot' => 0x1001e1e,
   'fabovedot' => 0x1001e1f,
   'Mabovedot' => 0x1001e40,
   'mabovedot' => 0x1001e41,
   'Pabovedot' => 0x1001e56,
   'wgrave' => 0x1001e81,
   'pabovedot' => 0x1001e57,
   'wacute' => 0x1001e83,
   'Sabovedot' => 0x1001e60,
   'ygrave' => 0x1001ef3,
   'Wdiaeresis' => 0x1001e84,
   'wdiaeresis' => 0x1001e85,
   'sabovedot' => 0x1001e61,
   'Wcircumflex' => 0x1000174,
   'Tabovedot' => 0x1001e6a,
   'Ycircumflex' => 0x1000176,
   'wcircumflex' => 0x1000175,
   'tabovedot' => 0x1001e6b,
   'ycircumflex' => 0x1000177,
   'OE' => 0x13bc,
   'oe' => 0x13bd,
   'Ydiaeresis' => 0x13be,
   'overline' => 0x47e,
   'kana_fullstop' => 0x4a1,
   'kana_openingbracket' => 0x4a2,
   'kana_closingbracket' => 0x4a3,
   'kana_comma' => 0x4a4,
   'kana_conjunctive' => 0x4a5,
   'kana_middledot' => 0x4a5,
   'kana_WO' => 0x4a6,
   'kana_a' => 0x4a7,
   'kana_i' => 0x4a8,
   'kana_u' => 0x4a9,
   'kana_e' => 0x4aa,
   'kana_o' => 0x4ab,
   'kana_ya' => 0x4ac,
   'kana_yu' => 0x4ad,
   'kana_yo' => 0x4ae,
   'kana_tsu' => 0x4af,
   'kana_tu' => 0x4af,
   'prolongedsound' => 0x4b0,
   'kana_A' => 0x4b1,
   'kana_I' => 0x4b2,
   'kana_U' => 0x4b3,
   'kana_E' => 0x4b4,
   'kana_O' => 0x4b5,
   'kana_KA' => 0x4b6,
   'kana_KI' => 0x4b7,
   'kana_KU' => 0x4b8,
   'kana_KE' => 0x4b9,
   'kana_KO' => 0x4ba,
   'kana_SA' => 0x4bb,
   'kana_SHI' => 0x4bc,
   'kana_SU' => 0x4bd,
   'kana_SE' => 0x4be,
   'kana_SO' => 0x4bf,
   'kana_TA' => 0x4c0,
   'kana_CHI' => 0x4c1,
   'kana_TI' => 0x4c1,
   'kana_TSU' => 0x4c2,
   'kana_TU' => 0x4c2,
   'kana_TE' => 0x4c3,
   'kana_TO' => 0x4c4,
   'kana_NA' => 0x4c5,
   'kana_NI' => 0x4c6,
   'kana_NU' => 0x4c7,
   'kana_NE' => 0x4c8,
   'kana_NO' => 0x4c9,
   'kana_HA' => 0x4ca,
   'kana_HI' => 0x4cb,
   'kana_FU' => 0x4cc,
   'kana_HU' => 0x4cc,
   'kana_HE' => 0x4cd,
   'kana_HO' => 0x4ce,
   'kana_MA' => 0x4cf,
   'kana_MI' => 0x4d0,
   'kana_MU' => 0x4d1,
   'kana_ME' => 0x4d2,
   'kana_MO' => 0x4d3,
   'kana_YA' => 0x4d4,
   'kana_YU' => 0x4d5,
   'kana_YO' => 0x4d6,
   'kana_RA' => 0x4d7,
   'kana_RI' => 0x4d8,
   'kana_RU' => 0x4d9,
   'kana_RE' => 0x4da,
   'kana_RO' => 0x4db,
   'kana_WA' => 0x4dc,
   'kana_N' => 0x4dd,
   'voicedsound' => 0x4de,
   'semivoicedsound' => 0x4df,
   'kana_switch' => 0xff7e,
   'Farsi_0' => 0x10006f0,
   'Farsi_1' => 0x10006f1,
   'Farsi_2' => 0x10006f2,
   'Farsi_3' => 0x10006f3,
   'Farsi_4' => 0x10006f4,
   'Farsi_5' => 0x10006f5,
   'Farsi_6' => 0x10006f6,
   'Farsi_7' => 0x10006f7,
   'Farsi_8' => 0x10006f8,
   'Farsi_9' => 0x10006f9,
   'Arabic_percent' => 0x100066a,
   'Arabic_superscript_alef' => 0x1000670,
   'Arabic_tteh' => 0x1000679,
   'Arabic_peh' => 0x100067e,
   'Arabic_tcheh' => 0x1000686,
   'Arabic_ddal' => 0x1000688,
   'Arabic_rreh' => 0x1000691,
   'Arabic_comma' => 0x5ac,
   'Arabic_fullstop' => 0x10006d4,
   'Arabic_0' => 0x1000660,
   'Arabic_1' => 0x1000661,
   'Arabic_2' => 0x1000662,
   'Arabic_3' => 0x1000663,
   'Arabic_4' => 0x1000664,
   'Arabic_5' => 0x1000665,
   'Arabic_6' => 0x1000666,
   'Arabic_7' => 0x1000667,
   'Arabic_8' => 0x1000668,
   'Arabic_9' => 0x1000669,
   'Arabic_semicolon' => 0x5bb,
   'Arabic_question_mark' => 0x5bf,
   'Arabic_hamza' => 0x5c1,
   'Arabic_maddaonalef' => 0x5c2,
   'Arabic_hamzaonalef' => 0x5c3,
   'Arabic_hamzaonwaw' => 0x5c4,
   'Arabic_hamzaunderalef' => 0x5c5,
   'Arabic_hamzaonyeh' => 0x5c6,
   'Arabic_alef' => 0x5c7,
   'Arabic_beh' => 0x5c8,
   'Arabic_tehmarbuta' => 0x5c9,
   'Arabic_teh' => 0x5ca,
   'Arabic_theh' => 0x5cb,
   'Arabic_jeem' => 0x5cc,
   'Arabic_hah' => 0x5cd,
   'Arabic_khah' => 0x5ce,
   'Arabic_dal' => 0x5cf,
   'Arabic_thal' => 0x5d0,
   'Arabic_ra' => 0x5d1,
   'Arabic_zain' => 0x5d2,
   'Arabic_seen' => 0x5d3,
   'Arabic_sheen' => 0x5d4,
   'Arabic_sad' => 0x5d5,
   'Arabic_dad' => 0x5d6,
   'Arabic_tah' => 0x5d7,
   'Arabic_zah' => 0x5d8,
   'Arabic_ain' => 0x5d9,
   'Arabic_ghain' => 0x5da,
   'Arabic_tatweel' => 0x5e0,
   'Arabic_feh' => 0x5e1,
   'Arabic_qaf' => 0x5e2,
   'Arabic_kaf' => 0x5e3,
   'Arabic_lam' => 0x5e4,
   'Arabic_meem' => 0x5e5,
   'Arabic_noon' => 0x5e6,
   'Arabic_ha' => 0x5e7,
   'Arabic_heh' => 0x5e7,
   'Arabic_waw' => 0x5e8,
   'Arabic_alefmaksura' => 0x5e9,
   'Arabic_yeh' => 0x5ea,
   'Arabic_fathatan' => 0x5eb,
   'Arabic_dammatan' => 0x5ec,
   'Arabic_kasratan' => 0x5ed,
   'Arabic_fatha' => 0x5ee,
   'Arabic_damma' => 0x5ef,
   'Arabic_kasra' => 0x5f0,
   'Arabic_shadda' => 0x5f1,
   'Arabic_sukun' => 0x5f2,
   'Arabic_madda_above' => 0x1000653,
   'Arabic_hamza_above' => 0x1000654,
   'Arabic_hamza_below' => 0x1000655,
   'Arabic_jeh' => 0x1000698,
   'Arabic_veh' => 0x10006a4,
   'Arabic_keheh' => 0x10006a9,
   'Arabic_gaf' => 0x10006af,
   'Arabic_noon_ghunna' => 0x10006ba,
   'Arabic_heh_doachashmee' => 0x10006be,
   'Farsi_yeh' => 0x10006cc,
   'Arabic_farsi_yeh' => 0x10006cc,
   'Arabic_yeh_baree' => 0x10006d2,
   'Arabic_heh_goal' => 0x10006c1,
   'Arabic_switch' => 0xff7e,
   'Cyrillic_GHE_bar' => 0x1000492,
   'Cyrillic_ghe_bar' => 0x1000493,
   'Cyrillic_ZHE_descender' => 0x1000496,
   'Cyrillic_zhe_descender' => 0x1000497,
   'Cyrillic_KA_descender' => 0x100049a,
   'Cyrillic_ka_descender' => 0x100049b,
   'Cyrillic_KA_vertstroke' => 0x100049c,
   'Cyrillic_ka_vertstroke' => 0x100049d,
   'Cyrillic_EN_descender' => 0x10004a2,
   'Cyrillic_en_descender' => 0x10004a3,
   'Cyrillic_U_straight' => 0x10004ae,
   'Cyrillic_u_straight' => 0x10004af,
   'Cyrillic_U_straight_bar' => 0x10004b0,
   'Cyrillic_u_straight_bar' => 0x10004b1,
   'Cyrillic_HA_descender' => 0x10004b2,
   'Cyrillic_ha_descender' => 0x10004b3,
   'Cyrillic_CHE_descender' => 0x10004b6,
   'Cyrillic_che_descender' => 0x10004b7,
   'Cyrillic_CHE_vertstroke' => 0x10004b8,
   'Cyrillic_che_vertstroke' => 0x10004b9,
   'Cyrillic_SHHA' => 0x10004ba,
   'Cyrillic_shha' => 0x10004bb,
   'Cyrillic_SCHWA' => 0x10004d8,
   'Cyrillic_schwa' => 0x10004d9,
   'Cyrillic_I_macron' => 0x10004e2,
   'Cyrillic_i_macron' => 0x10004e3,
   'Cyrillic_O_bar' => 0x10004e8,
   'Cyrillic_o_bar' => 0x10004e9,
   'Cyrillic_U_macron' => 0x10004ee,
   'Cyrillic_u_macron' => 0x10004ef,
   'Serbian_dje' => 0x6a1,
   'Macedonia_gje' => 0x6a2,
   'Cyrillic_io' => 0x6a3,
   'Ukrainian_ie' => 0x6a4,
   'Ukranian_je' => 0x6a4,
   'Macedonia_dse' => 0x6a5,
   'Ukrainian_i' => 0x6a6,
   'Ukranian_i' => 0x6a6,
   'Ukrainian_yi' => 0x6a7,
   'Ukranian_yi' => 0x6a7,
   'Cyrillic_je' => 0x6a8,
   'Serbian_je' => 0x6a8,
   'Cyrillic_lje' => 0x6a9,
   'Serbian_lje' => 0x6a9,
   'Cyrillic_nje' => 0x6aa,
   'Serbian_nje' => 0x6aa,
   'Serbian_tshe' => 0x6ab,
   'Macedonia_kje' => 0x6ac,
   'Ukrainian_ghe_with_upturn' => 0x6ad,
   'Byelorussian_shortu' => 0x6ae,
   'Cyrillic_dzhe' => 0x6af,
   'Serbian_dze' => 0x6af,
   'numerosign' => 0x6b0,
   'Serbian_DJE' => 0x6b1,
   'Macedonia_GJE' => 0x6b2,
   'Cyrillic_IO' => 0x6b3,
   'Ukrainian_IE' => 0x6b4,
   'Ukranian_JE' => 0x6b4,
   'Macedonia_DSE' => 0x6b5,
   'Ukrainian_I' => 0x6b6,
   'Ukranian_I' => 0x6b6,
   'Ukrainian_YI' => 0x6b7,
   'Ukranian_YI' => 0x6b7,
   'Cyrillic_JE' => 0x6b8,
   'Serbian_JE' => 0x6b8,
   'Cyrillic_LJE' => 0x6b9,
   'Serbian_LJE' => 0x6b9,
   'Cyrillic_NJE' => 0x6ba,
   'Serbian_NJE' => 0x6ba,
   'Serbian_TSHE' => 0x6bb,
   'Macedonia_KJE' => 0x6bc,
   'Ukrainian_GHE_WITH_UPTURN' => 0x6bd,
   'Byelorussian_SHORTU' => 0x6be,
   'Cyrillic_DZHE' => 0x6bf,
   'Serbian_DZE' => 0x6bf,
   'Cyrillic_yu' => 0x6c0,
   'Cyrillic_a' => 0x6c1,
   'Cyrillic_be' => 0x6c2,
   'Cyrillic_tse' => 0x6c3,
   'Cyrillic_de' => 0x6c4,
   'Cyrillic_ie' => 0x6c5,
   'Cyrillic_ef' => 0x6c6,
   'Cyrillic_ghe' => 0x6c7,
   'Cyrillic_ha' => 0x6c8,
   'Cyrillic_i' => 0x6c9,
   'Cyrillic_shorti' => 0x6ca,
   'Cyrillic_ka' => 0x6cb,
   'Cyrillic_el' => 0x6cc,
   'Cyrillic_em' => 0x6cd,
   'Cyrillic_en' => 0x6ce,
   'Cyrillic_o' => 0x6cf,
   'Cyrillic_pe' => 0x6d0,
   'Cyrillic_ya' => 0x6d1,
   'Cyrillic_er' => 0x6d2,
   'Cyrillic_es' => 0x6d3,
   'Cyrillic_te' => 0x6d4,
   'Cyrillic_u' => 0x6d5,
   'Cyrillic_zhe' => 0x6d6,
   'Cyrillic_ve' => 0x6d7,
   'Cyrillic_softsign' => 0x6d8,
   'Cyrillic_yeru' => 0x6d9,
   'Cyrillic_ze' => 0x6da,
   'Cyrillic_sha' => 0x6db,
   'Cyrillic_e' => 0x6dc,
   'Cyrillic_shcha' => 0x6dd,
   'Cyrillic_che' => 0x6de,
   'Cyrillic_hardsign' => 0x6df,
   'Cyrillic_YU' => 0x6e0,
   'Cyrillic_A' => 0x6e1,
   'Cyrillic_BE' => 0x6e2,
   'Cyrillic_TSE' => 0x6e3,
   'Cyrillic_DE' => 0x6e4,
   'Cyrillic_IE' => 0x6e5,
   'Cyrillic_EF' => 0x6e6,
   'Cyrillic_GHE' => 0x6e7,
   'Cyrillic_HA' => 0x6e8,
   'Cyrillic_I' => 0x6e9,
   'Cyrillic_SHORTI' => 0x6ea,
   'Cyrillic_KA' => 0x6eb,
   'Cyrillic_EL' => 0x6ec,
   'Cyrillic_EM' => 0x6ed,
   'Cyrillic_EN' => 0x6ee,
   'Cyrillic_O' => 0x6ef,
   'Cyrillic_PE' => 0x6f0,
   'Cyrillic_YA' => 0x6f1,
   'Cyrillic_ER' => 0x6f2,
   'Cyrillic_ES' => 0x6f3,
   'Cyrillic_TE' => 0x6f4,
   'Cyrillic_U' => 0x6f5,
   'Cyrillic_ZHE' => 0x6f6,
   'Cyrillic_VE' => 0x6f7,
   'Cyrillic_SOFTSIGN' => 0x6f8,
   'Cyrillic_YERU' => 0x6f9,
   'Cyrillic_ZE' => 0x6fa,
   'Cyrillic_SHA' => 0x6fb,
   'Cyrillic_E' => 0x6fc,
   'Cyrillic_SHCHA' => 0x6fd,
   'Cyrillic_CHE' => 0x6fe,
   'Cyrillic_HARDSIGN' => 0x6ff,
   'Greek_ALPHAaccent' => 0x7a1,
   'Greek_EPSILONaccent' => 0x7a2,
   'Greek_ETAaccent' => 0x7a3,
   'Greek_IOTAaccent' => 0x7a4,
   'Greek_IOTAdieresis' => 0x7a5,
   'Greek_IOTAdiaeresis' => 0x7a5,
   'Greek_OMICRONaccent' => 0x7a7,
   'Greek_UPSILONaccent' => 0x7a8,
   'Greek_UPSILONdieresis' => 0x7a9,
   'Greek_OMEGAaccent' => 0x7ab,
   'Greek_accentdieresis' => 0x7ae,
   'Greek_horizbar' => 0x7af,
   'Greek_alphaaccent' => 0x7b1,
   'Greek_epsilonaccent' => 0x7b2,
   'Greek_etaaccent' => 0x7b3,
   'Greek_iotaaccent' => 0x7b4,
   'Greek_iotadieresis' => 0x7b5,
   'Greek_iotaaccentdieresis' => 0x7b6,
   'Greek_omicronaccent' => 0x7b7,
   'Greek_upsilonaccent' => 0x7b8,
   'Greek_upsilondieresis' => 0x7b9,
   'Greek_upsilonaccentdieresis' => 0x7ba,
   'Greek_omegaaccent' => 0x7bb,
   'Greek_ALPHA' => 0x7c1,
   'Greek_BETA' => 0x7c2,
   'Greek_GAMMA' => 0x7c3,
   'Greek_DELTA' => 0x7c4,
   'Greek_EPSILON' => 0x7c5,
   'Greek_ZETA' => 0x7c6,
   'Greek_ETA' => 0x7c7,
   'Greek_THETA' => 0x7c8,
   'Greek_IOTA' => 0x7c9,
   'Greek_KAPPA' => 0x7ca,
   'Greek_LAMDA' => 0x7cb,
   'Greek_LAMBDA' => 0x7cb,
   'Greek_MU' => 0x7cc,
   'Greek_NU' => 0x7cd,
   'Greek_XI' => 0x7ce,
   'Greek_OMICRON' => 0x7cf,
   'Greek_PI' => 0x7d0,
   'Greek_RHO' => 0x7d1,
   'Greek_SIGMA' => 0x7d2,
   'Greek_TAU' => 0x7d4,
   'Greek_UPSILON' => 0x7d5,
   'Greek_PHI' => 0x7d6,
   'Greek_CHI' => 0x7d7,
   'Greek_PSI' => 0x7d8,
   'Greek_OMEGA' => 0x7d9,
   'Greek_alpha' => 0x7e1,
   'Greek_beta' => 0x7e2,
   'Greek_gamma' => 0x7e3,
   'Greek_delta' => 0x7e4,
   'Greek_epsilon' => 0x7e5,
   'Greek_zeta' => 0x7e6,
   'Greek_eta' => 0x7e7,
   'Greek_theta' => 0x7e8,
   'Greek_iota' => 0x7e9,
   'Greek_kappa' => 0x7ea,
   'Greek_lamda' => 0x7eb,
   'Greek_lambda' => 0x7eb,
   'Greek_mu' => 0x7ec,
   'Greek_nu' => 0x7ed,
   'Greek_xi' => 0x7ee,
   'Greek_omicron' => 0x7ef,
   'Greek_pi' => 0x7f0,
   'Greek_rho' => 0x7f1,
   'Greek_sigma' => 0x7f2,
   'Greek_finalsmallsigma' => 0x7f3,
   'Greek_tau' => 0x7f4,
   'Greek_upsilon' => 0x7f5,
   'Greek_phi' => 0x7f6,
   'Greek_chi' => 0x7f7,
   'Greek_psi' => 0x7f8,
   'Greek_omega' => 0x7f9,
   'Greek_switch' => 0xff7e,
   'leftradical' => 0x8a1,
   'topleftradical' => 0x8a2,
   'horizconnector' => 0x8a3,
   'topintegral' => 0x8a4,
   'botintegral' => 0x8a5,
   'vertconnector' => 0x8a6,
   'topleftsqbracket' => 0x8a7,
   'botleftsqbracket' => 0x8a8,
   'toprightsqbracket' => 0x8a9,
   'botrightsqbracket' => 0x8aa,
   'topleftparens' => 0x8ab,
   'botleftparens' => 0x8ac,
   'toprightparens' => 0x8ad,
   'botrightparens' => 0x8ae,
   'leftmiddlecurlybrace' => 0x8af,
   'rightmiddlecurlybrace' => 0x8b0,
   'topleftsummation' => 0x8b1,
   'botleftsummation' => 0x8b2,
   'topvertsummationconnector' => 0x8b3,
   'botvertsummationconnector' => 0x8b4,
   'toprightsummation' => 0x8b5,
   'botrightsummation' => 0x8b6,
   'rightmiddlesummation' => 0x8b7,
   'lessthanequal' => 0x8bc,
   'notequal' => 0x8bd,
   'greaterthanequal' => 0x8be,
   'integral' => 0x8bf,
   'therefore' => 0x8c0,
   'variation' => 0x8c1,
   'infinity' => 0x8c2,
   'nabla' => 0x8c5,
   'approximate' => 0x8c8,
   'similarequal' => 0x8c9,
   'ifonlyif' => 0x8cd,
   'implies' => 0x8ce,
   'identical' => 0x8cf,
   'radical' => 0x8d6,
   'includedin' => 0x8da,
   'includes' => 0x8db,
   'intersection' => 0x8dc,
   'union' => 0x8dd,
   'logicaland' => 0x8de,
   'logicalor' => 0x8df,
   'partialderivative' => 0x8ef,
   'function' => 0x8f6,
   'leftarrow' => 0x8fb,
   'uparrow' => 0x8fc,
   'rightarrow' => 0x8fd,
   'downarrow' => 0x8fe,
   'blank' => 0x9df,
   'soliddiamond' => 0x9e0,
   'checkerboard' => 0x9e1,
   'ht' => 0x9e2,
   'ff' => 0x9e3,
   'cr' => 0x9e4,
   'lf' => 0x9e5,
   'nl' => 0x9e8,
   'vt' => 0x9e9,
   'lowrightcorner' => 0x9ea,
   'uprightcorner' => 0x9eb,
   'upleftcorner' => 0x9ec,
   'lowleftcorner' => 0x9ed,
   'crossinglines' => 0x9ee,
   'horizlinescan1' => 0x9ef,
   'horizlinescan3' => 0x9f0,
   'horizlinescan5' => 0x9f1,
   'horizlinescan7' => 0x9f2,
   'horizlinescan9' => 0x9f3,
   'leftt' => 0x9f4,
   'rightt' => 0x9f5,
   'bott' => 0x9f6,
   'topt' => 0x9f7,
   'vertbar' => 0x9f8,
   'emspace' => 0xaa1,
   'enspace' => 0xaa2,
   'em3space' => 0xaa3,
   'em4space' => 0xaa4,
   'digitspace' => 0xaa5,
   'punctspace' => 0xaa6,
   'thinspace' => 0xaa7,
   'hairspace' => 0xaa8,
   'emdash' => 0xaa9,
   'endash' => 0xaaa,
   'signifblank' => 0xaac,
   'ellipsis' => 0xaae,
   'doubbaselinedot' => 0xaaf,
   'onethird' => 0xab0,
   'twothirds' => 0xab1,
   'onefifth' => 0xab2,
   'twofifths' => 0xab3,
   'threefifths' => 0xab4,
   'fourfifths' => 0xab5,
   'onesixth' => 0xab6,
   'fivesixths' => 0xab7,
   'careof' => 0xab8,
   'figdash' => 0xabb,
   'leftanglebracket' => 0xabc,
   'decimalpoint' => 0xabd,
   'rightanglebracket' => 0xabe,
   'marker' => 0xabf,
   'oneeighth' => 0xac3,
   'threeeighths' => 0xac4,
   'fiveeighths' => 0xac5,
   'seveneighths' => 0xac6,
   'trademark' => 0xac9,
   'signaturemark' => 0xaca,
   'trademarkincircle' => 0xacb,
   'leftopentriangle' => 0xacc,
   'rightopentriangle' => 0xacd,
   'emopencircle' => 0xace,
   'emopenrectangle' => 0xacf,
   'leftsinglequotemark' => 0xad0,
   'rightsinglequotemark' => 0xad1,
   'leftdoublequotemark' => 0xad2,
   'rightdoublequotemark' => 0xad3,
   'prescription' => 0xad4,
   'minutes' => 0xad6,
   'seconds' => 0xad7,
   'latincross' => 0xad9,
   'hexagram' => 0xada,
   'filledrectbullet' => 0xadb,
   'filledlefttribullet' => 0xadc,
   'filledrighttribullet' => 0xadd,
   'emfilledcircle' => 0xade,
   'emfilledrect' => 0xadf,
   'enopencircbullet' => 0xae0,
   'enopensquarebullet' => 0xae1,
   'openrectbullet' => 0xae2,
   'opentribulletup' => 0xae3,
   'opentribulletdown' => 0xae4,
   'openstar' => 0xae5,
   'enfilledcircbullet' => 0xae6,
   'enfilledsqbullet' => 0xae7,
   'filledtribulletup' => 0xae8,
   'filledtribulletdown' => 0xae9,
   'leftpointer' => 0xaea,
   'rightpointer' => 0xaeb,
   'club' => 0xaec,
   'diamond' => 0xaed,
   'heart' => 0xaee,
   'maltesecross' => 0xaf0,
   'dagger' => 0xaf1,
   'doubledagger' => 0xaf2,
   'checkmark' => 0xaf3,
   'ballotcross' => 0xaf4,
   'musicalsharp' => 0xaf5,
   'musicalflat' => 0xaf6,
   'malesymbol' => 0xaf7,
   'femalesymbol' => 0xaf8,
   'telephone' => 0xaf9,
   'telephonerecorder' => 0xafa,
   'phonographcopyright' => 0xafb,
   'caret' => 0xafc,
   'singlelowquotemark' => 0xafd,
   'doublelowquotemark' => 0xafe,
   'cursor' => 0xaff,
   'leftcaret' => 0xba3,
   'rightcaret' => 0xba6,
   'downcaret' => 0xba8,
   'upcaret' => 0xba9,
   'overbar' => 0xbc0,
   'downtack' => 0xbc2,
   'upshoe' => 0xbc3,
   'downstile' => 0xbc4,
   'underbar' => 0xbc6,
   'jot' => 0xbca,
   'quad' => 0xbcc,
   'uptack' => 0xbce,
   'circle' => 0xbcf,
   'upstile' => 0xbd3,
   'downshoe' => 0xbd6,
   'rightshoe' => 0xbd8,
   'leftshoe' => 0xbda,
   'lefttack' => 0xbdc,
   'righttack' => 0xbfc,
   'hebrew_doublelowline' => 0xcdf,
   'hebrew_aleph' => 0xce0,
   'hebrew_bet' => 0xce1,
   'hebrew_beth' => 0xce1,
   'hebrew_gimel' => 0xce2,
   'hebrew_gimmel' => 0xce2,
   'hebrew_dalet' => 0xce3,
   'hebrew_daleth' => 0xce3,
   'hebrew_he' => 0xce4,
   'hebrew_waw' => 0xce5,
   'hebrew_zain' => 0xce6,
   'hebrew_zayin' => 0xce6,
   'hebrew_chet' => 0xce7,
   'hebrew_het' => 0xce7,
   'hebrew_tet' => 0xce8,
   'hebrew_teth' => 0xce8,
   'hebrew_yod' => 0xce9,
   'hebrew_finalkaph' => 0xcea,
   'hebrew_kaph' => 0xceb,
   'hebrew_lamed' => 0xcec,
   'hebrew_finalmem' => 0xced,
   'hebrew_mem' => 0xcee,
   'hebrew_finalnun' => 0xcef,
   'hebrew_nun' => 0xcf0,
   'hebrew_samech' => 0xcf1,
   'hebrew_samekh' => 0xcf1,
   'hebrew_ayin' => 0xcf2,
   'hebrew_finalpe' => 0xcf3,
   'hebrew_pe' => 0xcf4,
   'hebrew_finalzade' => 0xcf5,
   'hebrew_finalzadi' => 0xcf5,
   'hebrew_zade' => 0xcf6,
   'hebrew_zadi' => 0xcf6,
   'hebrew_qoph' => 0xcf7,
   'hebrew_kuf' => 0xcf7,
   'hebrew_resh' => 0xcf8,
   'hebrew_shin' => 0xcf9,
   'hebrew_taw' => 0xcfa,
   'hebrew_taf' => 0xcfa,
   'Hebrew_switch' => 0xff7e,
   'Thai_kokai' => 0xda1,
   'Thai_khokhai' => 0xda2,
   'Thai_khokhuat' => 0xda3,
   'Thai_khokhwai' => 0xda4,
   'Thai_khokhon' => 0xda5,
   'Thai_khorakhang' => 0xda6,
   'Thai_ngongu' => 0xda7,
   'Thai_chochan' => 0xda8,
   'Thai_choching' => 0xda9,
   'Thai_chochang' => 0xdaa,
   'Thai_soso' => 0xdab,
   'Thai_chochoe' => 0xdac,
   'Thai_yoying' => 0xdad,
   'Thai_dochada' => 0xdae,
   'Thai_topatak' => 0xdaf,
   'Thai_thothan' => 0xdb0,
   'Thai_thonangmontho' => 0xdb1,
   'Thai_thophuthao' => 0xdb2,
   'Thai_nonen' => 0xdb3,
   'Thai_dodek' => 0xdb4,
   'Thai_totao' => 0xdb5,
   'Thai_thothung' => 0xdb6,
   'Thai_thothahan' => 0xdb7,
   'Thai_thothong' => 0xdb8,
   'Thai_nonu' => 0xdb9,
   'Thai_bobaimai' => 0xdba,
   'Thai_popla' => 0xdbb,
   'Thai_phophung' => 0xdbc,
   'Thai_fofa' => 0xdbd,
   'Thai_phophan' => 0xdbe,
   'Thai_fofan' => 0xdbf,
   'Thai_phosamphao' => 0xdc0,
   'Thai_moma' => 0xdc1,
   'Thai_yoyak' => 0xdc2,
   'Thai_rorua' => 0xdc3,
   'Thai_ru' => 0xdc4,
   'Thai_loling' => 0xdc5,
   'Thai_lu' => 0xdc6,
   'Thai_wowaen' => 0xdc7,
   'Thai_sosala' => 0xdc8,
   'Thai_sorusi' => 0xdc9,
   'Thai_sosua' => 0xdca,
   'Thai_hohip' => 0xdcb,
   'Thai_lochula' => 0xdcc,
   'Thai_oang' => 0xdcd,
   'Thai_honokhuk' => 0xdce,
   'Thai_paiyannoi' => 0xdcf,
   'Thai_saraa' => 0xdd0,
   'Thai_maihanakat' => 0xdd1,
   'Thai_saraaa' => 0xdd2,
   'Thai_saraam' => 0xdd3,
   'Thai_sarai' => 0xdd4,
   'Thai_saraii' => 0xdd5,
   'Thai_saraue' => 0xdd6,
   'Thai_sarauee' => 0xdd7,
   'Thai_sarau' => 0xdd8,
   'Thai_sarauu' => 0xdd9,
   'Thai_phinthu' => 0xdda,
   'Thai_maihanakat_maitho' => 0xdde,
   'Thai_baht' => 0xddf,
   'Thai_sarae' => 0xde0,
   'Thai_saraae' => 0xde1,
   'Thai_sarao' => 0xde2,
   'Thai_saraaimaimuan' => 0xde3,
   'Thai_saraaimaimalai' => 0xde4,
   'Thai_lakkhangyao' => 0xde5,
   'Thai_maiyamok' => 0xde6,
   'Thai_maitaikhu' => 0xde7,
   'Thai_maiek' => 0xde8,
   'Thai_maitho' => 0xde9,
   'Thai_maitri' => 0xdea,
   'Thai_maichattawa' => 0xdeb,
   'Thai_thanthakhat' => 0xdec,
   'Thai_nikhahit' => 0xded,
   'Thai_leksun' => 0xdf0,
   'Thai_leknung' => 0xdf1,
   'Thai_leksong' => 0xdf2,
   'Thai_leksam' => 0xdf3,
   'Thai_leksi' => 0xdf4,
   'Thai_lekha' => 0xdf5,
   'Thai_lekhok' => 0xdf6,
   'Thai_lekchet' => 0xdf7,
   'Thai_lekpaet' => 0xdf8,
   'Thai_lekkao' => 0xdf9,
   'Hangul' => 0xff31,
   'Hangul_Start' => 0xff32,
   'Hangul_End' => 0xff33,
   'Hangul_Hanja' => 0xff34,
   'Hangul_Jamo' => 0xff35,
   'Hangul_Romaja' => 0xff36,
   'Hangul_Codeinput' => 0xff37,
   'Hangul_Jeonja' => 0xff38,
   'Hangul_Banja' => 0xff39,
   'Hangul_PreHanja' => 0xff3a,
   'Hangul_PostHanja' => 0xff3b,
   'Hangul_SingleCandidate' => 0xff3c,
   'Hangul_MultipleCandidate' => 0xff3d,
   'Hangul_PreviousCandidate' => 0xff3e,
   'Hangul_Special' => 0xff3f,
   'Hangul_switch' => 0xff7e,
   'Hangul_Kiyeog' => 0xea1,
   'Hangul_SsangKiyeog' => 0xea2,
   'Hangul_KiyeogSios' => 0xea3,
   'Hangul_Nieun' => 0xea4,
   'Hangul_NieunJieuj' => 0xea5,
   'Hangul_NieunHieuh' => 0xea6,
   'Hangul_Dikeud' => 0xea7,
   'Hangul_SsangDikeud' => 0xea8,
   'Hangul_Rieul' => 0xea9,
   'Hangul_RieulKiyeog' => 0xeaa,
   'Hangul_RieulMieum' => 0xeab,
   'Hangul_RieulPieub' => 0xeac,
   'Hangul_RieulSios' => 0xead,
   'Hangul_RieulTieut' => 0xeae,
   'Hangul_RieulPhieuf' => 0xeaf,
   'Hangul_RieulHieuh' => 0xeb0,
   'Hangul_Mieum' => 0xeb1,
   'Hangul_Pieub' => 0xeb2,
   'Hangul_SsangPieub' => 0xeb3,
   'Hangul_PieubSios' => 0xeb4,
   'Hangul_Sios' => 0xeb5,
   'Hangul_SsangSios' => 0xeb6,
   'Hangul_Ieung' => 0xeb7,
   'Hangul_Jieuj' => 0xeb8,
   'Hangul_SsangJieuj' => 0xeb9,
   'Hangul_Cieuc' => 0xeba,
   'Hangul_Khieuq' => 0xebb,
   'Hangul_Tieut' => 0xebc,
   'Hangul_Phieuf' => 0xebd,
   'Hangul_Hieuh' => 0xebe,
   'Hangul_A' => 0xebf,
   'Hangul_AE' => 0xec0,
   'Hangul_YA' => 0xec1,
   'Hangul_YAE' => 0xec2,
   'Hangul_EO' => 0xec3,
   'Hangul_E' => 0xec4,
   'Hangul_YEO' => 0xec5,
   'Hangul_YE' => 0xec6,
   'Hangul_O' => 0xec7,
   'Hangul_WA' => 0xec8,
   'Hangul_WAE' => 0xec9,
   'Hangul_OE' => 0xeca,
   'Hangul_YO' => 0xecb,
   'Hangul_U' => 0xecc,
   'Hangul_WEO' => 0xecd,
   'Hangul_WE' => 0xece,
   'Hangul_WI' => 0xecf,
   'Hangul_YU' => 0xed0,
   'Hangul_EU' => 0xed1,
   'Hangul_YI' => 0xed2,
   'Hangul_I' => 0xed3,
   'Hangul_J_Kiyeog' => 0xed4,
   'Hangul_J_SsangKiyeog' => 0xed5,
   'Hangul_J_KiyeogSios' => 0xed6,
   'Hangul_J_Nieun' => 0xed7,
   'Hangul_J_NieunJieuj' => 0xed8,
   'Hangul_J_NieunHieuh' => 0xed9,
   'Hangul_J_Dikeud' => 0xeda,
   'Hangul_J_Rieul' => 0xedb,
   'Hangul_J_RieulKiyeog' => 0xedc,
   'Hangul_J_RieulMieum' => 0xedd,
   'Hangul_J_RieulPieub' => 0xede,
   'Hangul_J_RieulSios' => 0xedf,
   'Hangul_J_RieulTieut' => 0xee0,
   'Hangul_J_RieulPhieuf' => 0xee1,
   'Hangul_J_RieulHieuh' => 0xee2,
   'Hangul_J_Mieum' => 0xee3,
   'Hangul_J_Pieub' => 0xee4,
   'Hangul_J_PieubSios' => 0xee5,
   'Hangul_J_Sios' => 0xee6,
   'Hangul_J_SsangSios' => 0xee7,
   'Hangul_J_Ieung' => 0xee8,
   'Hangul_J_Jieuj' => 0xee9,
   'Hangul_J_Cieuc' => 0xeea,
   'Hangul_J_Khieuq' => 0xeeb,
   'Hangul_J_Tieut' => 0xeec,
   'Hangul_J_Phieuf' => 0xeed,
   'Hangul_J_Hieuh' => 0xeee,
   'Hangul_RieulYeorinHieuh' => 0xeef,
   'Hangul_SunkyeongeumMieum' => 0xef0,
   'Hangul_SunkyeongeumPieub' => 0xef1,
   'Hangul_PanSios' => 0xef2,
   'Hangul_KkogjiDalrinIeung' => 0xef3,
   'Hangul_SunkyeongeumPhieuf' => 0xef4,
   'Hangul_YeorinHieuh' => 0xef5,
   'Hangul_AraeA' => 0xef6,
   'Hangul_AraeAE' => 0xef7,
   'Hangul_J_PanSios' => 0xef8,
   'Hangul_J_KkogjiDalrinIeung' => 0xef9,
   'Hangul_J_YeorinHieuh' => 0xefa,
   'Korean_Won' => 0xeff,
   'Armenian_ligature_ew' => 0x1000587,
   'Armenian_full_stop' => 0x1000589,
   'Armenian_verjaket' => 0x1000589,
   'Armenian_separation_mark' => 0x100055d,
   'Armenian_but' => 0x100055d,
   'Armenian_hyphen' => 0x100058a,
   'Armenian_yentamna' => 0x100058a,
   'Armenian_exclam' => 0x100055c,
   'Armenian_amanak' => 0x100055c,
   'Armenian_accent' => 0x100055b,
   'Armenian_shesht' => 0x100055b,
   'Armenian_question' => 0x100055e,
   'Armenian_paruyk' => 0x100055e,
   'Armenian_AYB' => 0x1000531,
   'Armenian_ayb' => 0x1000561,
   'Armenian_BEN' => 0x1000532,
   'Armenian_ben' => 0x1000562,
   'Armenian_GIM' => 0x1000533,
   'Armenian_gim' => 0x1000563,
   'Armenian_DA' => 0x1000534,
   'Armenian_da' => 0x1000564,
   'Armenian_YECH' => 0x1000535,
   'Armenian_yech' => 0x1000565,
   'Armenian_ZA' => 0x1000536,
   'Armenian_za' => 0x1000566,
   'Armenian_E' => 0x1000537,
   'Armenian_e' => 0x1000567,
   'Armenian_AT' => 0x1000538,
   'Armenian_at' => 0x1000568,
   'Armenian_TO' => 0x1000539,
   'Armenian_to' => 0x1000569,
   'Armenian_ZHE' => 0x100053a,
   'Armenian_zhe' => 0x100056a,
   'Armenian_INI' => 0x100053b,
   'Armenian_ini' => 0x100056b,
   'Armenian_LYUN' => 0x100053c,
   'Armenian_lyun' => 0x100056c,
   'Armenian_KHE' => 0x100053d,
   'Armenian_khe' => 0x100056d,
   'Armenian_TSA' => 0x100053e,
   'Armenian_tsa' => 0x100056e,
   'Armenian_KEN' => 0x100053f,
   'Armenian_ken' => 0x100056f,
   'Armenian_HO' => 0x1000540,
   'Armenian_ho' => 0x1000570,
   'Armenian_DZA' => 0x1000541,
   'Armenian_dza' => 0x1000571,
   'Armenian_GHAT' => 0x1000542,
   'Armenian_ghat' => 0x1000572,
   'Armenian_TCHE' => 0x1000543,
   'Armenian_tche' => 0x1000573,
   'Armenian_MEN' => 0x1000544,
   'Armenian_men' => 0x1000574,
   'Armenian_HI' => 0x1000545,
   'Armenian_hi' => 0x1000575,
   'Armenian_NU' => 0x1000546,
   'Armenian_nu' => 0x1000576,
   'Armenian_SHA' => 0x1000547,
   'Armenian_sha' => 0x1000577,
   'Armenian_VO' => 0x1000548,
   'Armenian_vo' => 0x1000578,
   'Armenian_CHA' => 0x1000549,
   'Armenian_cha' => 0x1000579,
   'Armenian_PE' => 0x100054a,
   'Armenian_pe' => 0x100057a,
   'Armenian_JE' => 0x100054b,
   'Armenian_je' => 0x100057b,
   'Armenian_RA' => 0x100054c,
   'Armenian_ra' => 0x100057c,
   'Armenian_SE' => 0x100054d,
   'Armenian_se' => 0x100057d,
   'Armenian_VEV' => 0x100054e,
   'Armenian_vev' => 0x100057e,
   'Armenian_TYUN' => 0x100054f,
   'Armenian_tyun' => 0x100057f,
   'Armenian_RE' => 0x1000550,
   'Armenian_re' => 0x1000580,
   'Armenian_TSO' => 0x1000551,
   'Armenian_tso' => 0x1000581,
   'Armenian_VYUN' => 0x1000552,
   'Armenian_vyun' => 0x1000582,
   'Armenian_PYUR' => 0x1000553,
   'Armenian_pyur' => 0x1000583,
   'Armenian_KE' => 0x1000554,
   'Armenian_ke' => 0x1000584,
   'Armenian_O' => 0x1000555,
   'Armenian_o' => 0x1000585,
   'Armenian_FE' => 0x1000556,
   'Armenian_fe' => 0x1000586,
   'Armenian_apostrophe' => 0x100055a,
   'Georgian_an' => 0x10010d0,
   'Georgian_ban' => 0x10010d1,
   'Georgian_gan' => 0x10010d2,
   'Georgian_don' => 0x10010d3,
   'Georgian_en' => 0x10010d4,
   'Georgian_vin' => 0x10010d5,
   'Georgian_zen' => 0x10010d6,
   'Georgian_tan' => 0x10010d7,
   'Georgian_in' => 0x10010d8,
   'Georgian_kan' => 0x10010d9,
   'Georgian_las' => 0x10010da,
   'Georgian_man' => 0x10010db,
   'Georgian_nar' => 0x10010dc,
   'Georgian_on' => 0x10010dd,
   'Georgian_par' => 0x10010de,
   'Georgian_zhar' => 0x10010df,
   'Georgian_rae' => 0x10010e0,
   'Georgian_san' => 0x10010e1,
   'Georgian_tar' => 0x10010e2,
   'Georgian_un' => 0x10010e3,
   'Georgian_phar' => 0x10010e4,
   'Georgian_khar' => 0x10010e5,
   'Georgian_ghan' => 0x10010e6,
   'Georgian_qar' => 0x10010e7,
   'Georgian_shin' => 0x10010e8,
   'Georgian_chin' => 0x10010e9,
   'Georgian_can' => 0x10010ea,
   'Georgian_jil' => 0x10010eb,
   'Georgian_cil' => 0x10010ec,
   'Georgian_char' => 0x10010ed,
   'Georgian_xan' => 0x10010ee,
   'Georgian_jhan' => 0x10010ef,
   'Georgian_hae' => 0x10010f0,
   'Georgian_he' => 0x10010f1,
   'Georgian_hie' => 0x10010f2,
   'Georgian_we' => 0x10010f3,
   'Georgian_har' => 0x10010f4,
   'Georgian_hoe' => 0x10010f5,
   'Georgian_fi' => 0x10010f6,
   'Xabovedot' => 0x1001e8a,
   'Ibreve' => 0x100012c,
   'Zstroke' => 0x10001b5,
   'Gcaron' => 0x10001e6,
   'Ocaron' => 0x10001d1,
   'Obarred' => 0x100019f,
   'xabovedot' => 0x1001e8b,
   'ibreve' => 0x100012d,
   'zstroke' => 0x10001b6,
   'gcaron' => 0x10001e7,
   'ocaron' => 0x10001d2,
   'obarred' => 0x1000275,
   'SCHWA' => 0x100018f,
   'schwa' => 0x1000259,
   'Lbelowdot' => 0x1001e36,
   'lbelowdot' => 0x1001e37,
   'Abelowdot' => 0x1001ea0,
   'abelowdot' => 0x1001ea1,
   'Ahook' => 0x1001ea2,
   'ahook' => 0x1001ea3,
   'Acircumflexacute' => 0x1001ea4,
   'acircumflexacute' => 0x1001ea5,
   'Acircumflexgrave' => 0x1001ea6,
   'acircumflexgrave' => 0x1001ea7,
   'Acircumflexhook' => 0x1001ea8,
   'acircumflexhook' => 0x1001ea9,
   'Acircumflextilde' => 0x1001eaa,
   'acircumflextilde' => 0x1001eab,
   'Acircumflexbelowdot' => 0x1001eac,
   'acircumflexbelowdot' => 0x1001ead,
   'Abreveacute' => 0x1001eae,
   'abreveacute' => 0x1001eaf,
   'Abrevegrave' => 0x1001eb0,
   'abrevegrave' => 0x1001eb1,
   'Abrevehook' => 0x1001eb2,
   'abrevehook' => 0x1001eb3,
   'Abrevetilde' => 0x1001eb4,
   'abrevetilde' => 0x1001eb5,
   'Abrevebelowdot' => 0x1001eb6,
   'abrevebelowdot' => 0x1001eb7,
   'Ebelowdot' => 0x1001eb8,
   'ebelowdot' => 0x1001eb9,
   'Ehook' => 0x1001eba,
   'ehook' => 0x1001ebb,
   'Etilde' => 0x1001ebc,
   'etilde' => 0x1001ebd,
   'Ecircumflexacute' => 0x1001ebe,
   'ecircumflexacute' => 0x1001ebf,
   'Ecircumflexgrave' => 0x1001ec0,
   'ecircumflexgrave' => 0x1001ec1,
   'Ecircumflexhook' => 0x1001ec2,
   'ecircumflexhook' => 0x1001ec3,
   'Ecircumflextilde' => 0x1001ec4,
   'ecircumflextilde' => 0x1001ec5,
   'Ecircumflexbelowdot' => 0x1001ec6,
   'ecircumflexbelowdot' => 0x1001ec7,
   'Ihook' => 0x1001ec8,
   'ihook' => 0x1001ec9,
   'Ibelowdot' => 0x1001eca,
   'ibelowdot' => 0x1001ecb,
   'Obelowdot' => 0x1001ecc,
   'obelowdot' => 0x1001ecd,
   'Ohook' => 0x1001ece,
   'ohook' => 0x1001ecf,
   'Ocircumflexacute' => 0x1001ed0,
   'ocircumflexacute' => 0x1001ed1,
   'Ocircumflexgrave' => 0x1001ed2,
   'ocircumflexgrave' => 0x1001ed3,
   'Ocircumflexhook' => 0x1001ed4,
   'ocircumflexhook' => 0x1001ed5,
   'Ocircumflextilde' => 0x1001ed6,
   'ocircumflextilde' => 0x1001ed7,
   'Ocircumflexbelowdot' => 0x1001ed8,
   'ocircumflexbelowdot' => 0x1001ed9,
   'Ohornacute' => 0x1001eda,
   'ohornacute' => 0x1001edb,
   'Ohorngrave' => 0x1001edc,
   'ohorngrave' => 0x1001edd,
   'Ohornhook' => 0x1001ede,
   'ohornhook' => 0x1001edf,
   'Ohorntilde' => 0x1001ee0,
   'ohorntilde' => 0x1001ee1,
   'Ohornbelowdot' => 0x1001ee2,
   'ohornbelowdot' => 0x1001ee3,
   'Ubelowdot' => 0x1001ee4,
   'ubelowdot' => 0x1001ee5,
   'Uhook' => 0x1001ee6,
   'uhook' => 0x1001ee7,
   'Uhornacute' => 0x1001ee8,
   'uhornacute' => 0x1001ee9,
   'Uhorngrave' => 0x1001eea,
   'uhorngrave' => 0x1001eeb,
   'Uhornhook' => 0x1001eec,
   'uhornhook' => 0x1001eed,
   'Uhorntilde' => 0x1001eee,
   'uhorntilde' => 0x1001eef,
   'Uhornbelowdot' => 0x1001ef0,
   'uhornbelowdot' => 0x1001ef1,
   'Ybelowdot' => 0x1001ef4,
   'ybelowdot' => 0x1001ef5,
   'Yhook' => 0x1001ef6,
   'yhook' => 0x1001ef7,
   'Ytilde' => 0x1001ef8,
   'ytilde' => 0x1001ef9,
   'Ohorn' => 0x10001a0,
   'ohorn' => 0x10001a1,
   'Uhorn' => 0x10001af,
   'uhorn' => 0x10001b0,
   'EcuSign' => 0x10020a0,
   'ColonSign' => 0x10020a1,
   'CruzeiroSign' => 0x10020a2,
   'FFrancSign' => 0x10020a3,
   'LiraSign' => 0x10020a4,
   'MillSign' => 0x10020a5,
   'NairaSign' => 0x10020a6,
   'PesetaSign' => 0x10020a7,
   'RupeeSign' => 0x10020a8,
   'WonSign' => 0x10020a9,
   'NewSheqelSign' => 0x10020aa,
   'DongSign' => 0x10020ab,
   'EuroSign' => 0x20ac,
   'zerosuperior' => 0x1002070,
   'foursuperior' => 0x1002074,
   'fivesuperior' => 0x1002075,
   'sixsuperior' => 0x1002076,
   'sevensuperior' => 0x1002077,
   'eightsuperior' => 0x1002078,
   'ninesuperior' => 0x1002079,
   'zerosubscript' => 0x1002080,
   'onesubscript' => 0x1002081,
   'twosubscript' => 0x1002082,
   'threesubscript' => 0x1002083,
   'foursubscript' => 0x1002084,
   'fivesubscript' => 0x1002085,
   'sixsubscript' => 0x1002086,
   'sevensubscript' => 0x1002087,
   'eightsubscript' => 0x1002088,
   'ninesubscript' => 0x1002089,
   'partdifferential' => 0x1002202,
   'emptyset' => 0x1002205,
   'elementof' => 0x1002208,
   'notelementof' => 0x1002209,
   'containsas' => 0x100220b,
   'squareroot' => 0x100221a,
   'cuberoot' => 0x100221b,
   'fourthroot' => 0x100221c,
   'dintegral' => 0x100222c,
   'tintegral' => 0x100222d,
   'because' => 0x1002235,
   'approxeq' => 0x1002248,
   'notapproxeq' => 0x1002247,
   'notidentical' => 0x1002262,
   'stricteq' => 0x1002263,
   'braille_dot_1' => 0xfff1,
   'braille_dot_2' => 0xfff2,
   'braille_dot_3' => 0xfff3,
   'braille_dot_4' => 0xfff4,
   'braille_dot_5' => 0xfff5,
   'braille_dot_6' => 0xfff6,
   'braille_dot_7' => 0xfff7,
   'braille_dot_8' => 0xfff8,
   'braille_dot_9' => 0xfff9,
   'braille_dot_10' => 0xfffa,
   'braille_blank' => 0x1002800,
   'braille_dots_1' => 0x1002801,
   'braille_dots_2' => 0x1002802,
   'braille_dots_12' => 0x1002803,
   'braille_dots_3' => 0x1002804,
   'braille_dots_13' => 0x1002805,
   'braille_dots_23' => 0x1002806,
   'braille_dots_123' => 0x1002807,
   'braille_dots_4' => 0x1002808,
   'braille_dots_14' => 0x1002809,
   'braille_dots_24' => 0x100280a,
   'braille_dots_124' => 0x100280b,
   'braille_dots_34' => 0x100280c,
   'braille_dots_134' => 0x100280d,
   'braille_dots_234' => 0x100280e,
   'braille_dots_1234' => 0x100280f,
   'braille_dots_5' => 0x1002810,
   'braille_dots_15' => 0x1002811,
   'braille_dots_25' => 0x1002812,
   'braille_dots_125' => 0x1002813,
   'braille_dots_35' => 0x1002814,
   'braille_dots_135' => 0x1002815,
   'braille_dots_235' => 0x1002816,
   'braille_dots_1235' => 0x1002817,
   'braille_dots_45' => 0x1002818,
   'braille_dots_145' => 0x1002819,
   'braille_dots_245' => 0x100281a,
   'braille_dots_1245' => 0x100281b,
   'braille_dots_345' => 0x100281c,
   'braille_dots_1345' => 0x100281d,
   'braille_dots_2345' => 0x100281e,
   'braille_dots_12345' => 0x100281f,
   'braille_dots_6' => 0x1002820,
   'braille_dots_16' => 0x1002821,
   'braille_dots_26' => 0x1002822,
   'braille_dots_126' => 0x1002823,
   'braille_dots_36' => 0x1002824,
   'braille_dots_136' => 0x1002825,
   'braille_dots_236' => 0x1002826,
   'braille_dots_1236' => 0x1002827,
   'braille_dots_46' => 0x1002828,
   'braille_dots_146' => 0x1002829,
   'braille_dots_246' => 0x100282a,
   'braille_dots_1246' => 0x100282b,
   'braille_dots_346' => 0x100282c,
   'braille_dots_1346' => 0x100282d,
   'braille_dots_2346' => 0x100282e,
   'braille_dots_12346' => 0x100282f,
   'braille_dots_56' => 0x1002830,
   'braille_dots_156' => 0x1002831,
   'braille_dots_256' => 0x1002832,
   'braille_dots_1256' => 0x1002833,
   'braille_dots_356' => 0x1002834,
   'braille_dots_1356' => 0x1002835,
   'braille_dots_2356' => 0x1002836,
   'braille_dots_12356' => 0x1002837,
   'braille_dots_456' => 0x1002838,
   'braille_dots_1456' => 0x1002839,
   'braille_dots_2456' => 0x100283a,
   'braille_dots_12456' => 0x100283b,
   'braille_dots_3456' => 0x100283c,
   'braille_dots_13456' => 0x100283d,
   'braille_dots_23456' => 0x100283e,
   'braille_dots_123456' => 0x100283f,
   'braille_dots_7' => 0x1002840,
   'braille_dots_17' => 0x1002841,
   'braille_dots_27' => 0x1002842,
   'braille_dots_127' => 0x1002843,
   'braille_dots_37' => 0x1002844,
   'braille_dots_137' => 0x1002845,
   'braille_dots_237' => 0x1002846,
   'braille_dots_1237' => 0x1002847,
   'braille_dots_47' => 0x1002848,
   'braille_dots_147' => 0x1002849,
   'braille_dots_247' => 0x100284a,
   'braille_dots_1247' => 0x100284b,
   'braille_dots_347' => 0x100284c,
   'braille_dots_1347' => 0x100284d,
   'braille_dots_2347' => 0x100284e,
   'braille_dots_12347' => 0x100284f,
   'braille_dots_57' => 0x1002850,
   'braille_dots_157' => 0x1002851,
   'braille_dots_257' => 0x1002852,
   'braille_dots_1257' => 0x1002853,
   'braille_dots_357' => 0x1002854,
   'braille_dots_1357' => 0x1002855,
   'braille_dots_2357' => 0x1002856,
   'braille_dots_12357' => 0x1002857,
   'braille_dots_457' => 0x1002858,
   'braille_dots_1457' => 0x1002859,
   'braille_dots_2457' => 0x100285a,
   'braille_dots_12457' => 0x100285b,
   'braille_dots_3457' => 0x100285c,
   'braille_dots_13457' => 0x100285d,
   'braille_dots_23457' => 0x100285e,
   'braille_dots_123457' => 0x100285f,
   'braille_dots_67' => 0x1002860,
   'braille_dots_167' => 0x1002861,
   'braille_dots_267' => 0x1002862,
   'braille_dots_1267' => 0x1002863,
   'braille_dots_367' => 0x1002864,
   'braille_dots_1367' => 0x1002865,
   'braille_dots_2367' => 0x1002866,
   'braille_dots_12367' => 0x1002867,
   'braille_dots_467' => 0x1002868,
   'braille_dots_1467' => 0x1002869,
   'braille_dots_2467' => 0x100286a,
   'braille_dots_12467' => 0x100286b,
   'braille_dots_3467' => 0x100286c,
   'braille_dots_13467' => 0x100286d,
   'braille_dots_23467' => 0x100286e,
   'braille_dots_123467' => 0x100286f,
   'braille_dots_567' => 0x1002870,
   'braille_dots_1567' => 0x1002871,
   'braille_dots_2567' => 0x1002872,
   'braille_dots_12567' => 0x1002873,
   'braille_dots_3567' => 0x1002874,
   'braille_dots_13567' => 0x1002875,
   'braille_dots_23567' => 0x1002876,
   'braille_dots_123567' => 0x1002877,
   'braille_dots_4567' => 0x1002878,
   'braille_dots_14567' => 0x1002879,
   'braille_dots_24567' => 0x100287a,
   'braille_dots_124567' => 0x100287b,
   'braille_dots_34567' => 0x100287c,
   'braille_dots_134567' => 0x100287d,
   'braille_dots_234567' => 0x100287e,
   'braille_dots_1234567' => 0x100287f,
   'braille_dots_8' => 0x1002880,
   'braille_dots_18' => 0x1002881,
   'braille_dots_28' => 0x1002882,
   'braille_dots_128' => 0x1002883,
   'braille_dots_38' => 0x1002884,
   'braille_dots_138' => 0x1002885,
   'braille_dots_238' => 0x1002886,
   'braille_dots_1238' => 0x1002887,
   'braille_dots_48' => 0x1002888,
   'braille_dots_148' => 0x1002889,
   'braille_dots_248' => 0x100288a,
   'braille_dots_1248' => 0x100288b,
   'braille_dots_348' => 0x100288c,
   'braille_dots_1348' => 0x100288d,
   'braille_dots_2348' => 0x100288e,
   'braille_dots_12348' => 0x100288f,
   'braille_dots_58' => 0x1002890,
   'braille_dots_158' => 0x1002891,
   'braille_dots_258' => 0x1002892,
   'braille_dots_1258' => 0x1002893,
   'braille_dots_358' => 0x1002894,
   'braille_dots_1358' => 0x1002895,
   'braille_dots_2358' => 0x1002896,
   'braille_dots_12358' => 0x1002897,
   'braille_dots_458' => 0x1002898,
   'braille_dots_1458' => 0x1002899,
   'braille_dots_2458' => 0x100289a,
   'braille_dots_12458' => 0x100289b,
   'braille_dots_3458' => 0x100289c,
   'braille_dots_13458' => 0x100289d,
   'braille_dots_23458' => 0x100289e,
   'braille_dots_123458' => 0x100289f,
   'braille_dots_68' => 0x10028a0,
   'braille_dots_168' => 0x10028a1,
   'braille_dots_268' => 0x10028a2,
   'braille_dots_1268' => 0x10028a3,
   'braille_dots_368' => 0x10028a4,
   'braille_dots_1368' => 0x10028a5,
   'braille_dots_2368' => 0x10028a6,
   'braille_dots_12368' => 0x10028a7,
   'braille_dots_468' => 0x10028a8,
   'braille_dots_1468' => 0x10028a9,
   'braille_dots_2468' => 0x10028aa,
   'braille_dots_12468' => 0x10028ab,
   'braille_dots_3468' => 0x10028ac,
   'braille_dots_13468' => 0x10028ad,
   'braille_dots_23468' => 0x10028ae,
   'braille_dots_123468' => 0x10028af,
   'braille_dots_568' => 0x10028b0,
   'braille_dots_1568' => 0x10028b1,
   'braille_dots_2568' => 0x10028b2,
   'braille_dots_12568' => 0x10028b3,
   'braille_dots_3568' => 0x10028b4,
   'braille_dots_13568' => 0x10028b5,
   'braille_dots_23568' => 0x10028b6,
   'braille_dots_123568' => 0x10028b7,
   'braille_dots_4568' => 0x10028b8,
   'braille_dots_14568' => 0x10028b9,
   'braille_dots_24568' => 0x10028ba,
   'braille_dots_124568' => 0x10028bb,
   'braille_dots_34568' => 0x10028bc,
   'braille_dots_134568' => 0x10028bd,
   'braille_dots_234568' => 0x10028be,
   'braille_dots_1234568' => 0x10028bf,
   'braille_dots_78' => 0x10028c0,
   'braille_dots_178' => 0x10028c1,
   'braille_dots_278' => 0x10028c2,
   'braille_dots_1278' => 0x10028c3,
   'braille_dots_378' => 0x10028c4,
   'braille_dots_1378' => 0x10028c5,
   'braille_dots_2378' => 0x10028c6,
   'braille_dots_12378' => 0x10028c7,
   'braille_dots_478' => 0x10028c8,
   'braille_dots_1478' => 0x10028c9,
   'braille_dots_2478' => 0x10028ca,
   'braille_dots_12478' => 0x10028cb,
   'braille_dots_3478' => 0x10028cc,
   'braille_dots_13478' => 0x10028cd,
   'braille_dots_23478' => 0x10028ce,
   'braille_dots_123478' => 0x10028cf,
   'braille_dots_578' => 0x10028d0,
   'braille_dots_1578' => 0x10028d1,
   'braille_dots_2578' => 0x10028d2,
   'braille_dots_12578' => 0x10028d3,
   'braille_dots_3578' => 0x10028d4,
   'braille_dots_13578' => 0x10028d5,
   'braille_dots_23578' => 0x10028d6,
   'braille_dots_123578' => 0x10028d7,
   'braille_dots_4578' => 0x10028d8,
   'braille_dots_14578' => 0x10028d9,
   'braille_dots_24578' => 0x10028da,
   'braille_dots_124578' => 0x10028db,
   'braille_dots_34578' => 0x10028dc,
   'braille_dots_134578' => 0x10028dd,
   'braille_dots_234578' => 0x10028de,
   'braille_dots_1234578' => 0x10028df,
   'braille_dots_678' => 0x10028e0,
   'braille_dots_1678' => 0x10028e1,
   'braille_dots_2678' => 0x10028e2,
   'braille_dots_12678' => 0x10028e3,
   'braille_dots_3678' => 0x10028e4,
   'braille_dots_13678' => 0x10028e5,
   'braille_dots_23678' => 0x10028e6,
   'braille_dots_123678' => 0x10028e7,
   'braille_dots_4678' => 0x10028e8,
   'braille_dots_14678' => 0x10028e9,
   'braille_dots_24678' => 0x10028ea,
   'braille_dots_124678' => 0x10028eb,
   'braille_dots_34678' => 0x10028ec,
   'braille_dots_134678' => 0x10028ed,
   'braille_dots_234678' => 0x10028ee,
   'braille_dots_1234678' => 0x10028ef,
   'braille_dots_5678' => 0x10028f0,
   'braille_dots_15678' => 0x10028f1,
   'braille_dots_25678' => 0x10028f2,
   'braille_dots_125678' => 0x10028f3,
   'braille_dots_35678' => 0x10028f4,
   'braille_dots_135678' => 0x10028f5,
   'braille_dots_235678' => 0x10028f6,
   'braille_dots_1235678' => 0x10028f7,
   'braille_dots_45678' => 0x10028f8,
   'braille_dots_145678' => 0x10028f9,
   'braille_dots_245678' => 0x10028fa,
   'braille_dots_1245678' => 0x10028fb,
   'braille_dots_345678' => 0x10028fc,
   'braille_dots_1345678' => 0x10028fd,
   'braille_dots_2345678' => 0x10028fe,
   'braille_dots_12345678' => 0x10028ff,
   'ModeLock' => 0x1008ff01,
   'MonBrightnessUp' => 0x1008ff02,
   'MonBrightnessDown' => 0x1008ff03,
   'KbdLightOnOff' => 0x1008ff04,
   'KbdBrightnessUp' => 0x1008ff05,
   'KbdBrightnessDown' => 0x1008ff06,
   'Standby' => 0x1008ff10,
   'AudioLowerVolume' => 0x1008ff11,
   'AudioMute' => 0x1008ff12,
   'AudioRaiseVolume' => 0x1008ff13,
   'AudioPlay' => 0x1008ff14,
   'AudioStop' => 0x1008ff15,
   'AudioPrev' => 0x1008ff16,
   'AudioNext' => 0x1008ff17,
   'HomePage' => 0x1008ff18,
   'Mail' => 0x1008ff19,
   'Start' => 0x1008ff1a,
   'Search' => 0x1008ff1b,
   'AudioRecord' => 0x1008ff1c,
   'Calculator' => 0x1008ff1d,
   'Memo' => 0x1008ff1e,
   'ToDoList' => 0x1008ff1f,
   'Calendar' => 0x1008ff20,
   'PowerDown' => 0x1008ff21,
   'ContrastAdjust' => 0x1008ff22,
   'RockerUp' => 0x1008ff23,
   'RockerDown' => 0x1008ff24,
   'RockerEnter' => 0x1008ff25,
   'Back' => 0x1008ff26,
   'Forward' => 0x1008ff27,
   'Stop' => 0x1008ff28,
   'Refresh' => 0x1008ff29,
   'PowerOff' => 0x1008ff2a,
   'WakeUp' => 0x1008ff2b,
   'Eject' => 0x1008ff2c,
   'ScreenSaver' => 0x1008ff2d,
   'WWW' => 0x1008ff2e,
   'Sleep' => 0x1008ff2f,
   'Favorites' => 0x1008ff30,
   'AudioPause' => 0x1008ff31,
   'AudioMedia' => 0x1008ff32,
   'MyComputer' => 0x1008ff33,
   'VendorHome' => 0x1008ff34,
   'LightBulb' => 0x1008ff35,
   'Shop' => 0x1008ff36,
   'History' => 0x1008ff37,
   'OpenURL' => 0x1008ff38,
   'AddFavorite' => 0x1008ff39,
   'HotLinks' => 0x1008ff3a,
   'BrightnessAdjust' => 0x1008ff3b,
   'Finance' => 0x1008ff3c,
   'Community' => 0x1008ff3d,
   'AudioRewind' => 0x1008ff3e,
   'BackForward' => 0x1008ff3f,
   'Launch0' => 0x1008ff40,
   'Launch1' => 0x1008ff41,
   'Launch2' => 0x1008ff42,
   'Launch3' => 0x1008ff43,
   'Launch4' => 0x1008ff44,
   'Launch5' => 0x1008ff45,
   'Launch6' => 0x1008ff46,
   'Launch7' => 0x1008ff47,
   'Launch8' => 0x1008ff48,
   'Launch9' => 0x1008ff49,
   'LaunchA' => 0x1008ff4a,
   'LaunchB' => 0x1008ff4b,
   'LaunchC' => 0x1008ff4c,
   'LaunchD' => 0x1008ff4d,
   'LaunchE' => 0x1008ff4e,
   'LaunchF' => 0x1008ff4f,
   'ApplicationLeft' => 0x1008ff50,
   'ApplicationRight' => 0x1008ff51,
   'Book' => 0x1008ff52,
   'CD' => 0x1008ff53,
   'WindowClear' => 0x1008ff55,
   'Close' => 0x1008ff56,
   'Copy' => 0x1008ff57,
   'Cut' => 0x1008ff58,
   'Display' => 0x1008ff59,
   'DOS' => 0x1008ff5a,
   'Documents' => 0x1008ff5b,
   'Excel' => 0x1008ff5c,
   'Explorer' => 0x1008ff5d,
   'Game' => 0x1008ff5e,
   'Go' => 0x1008ff5f,
   'iTouch' => 0x1008ff60,
   'LogOff' => 0x1008ff61,
   'Market' => 0x1008ff62,
   'Meeting' => 0x1008ff63,
   'MenuKB' => 0x1008ff65,
   'MenuPB' => 0x1008ff66,
   'MySites' => 0x1008ff67,
   'New' => 0x1008ff68,
   'News' => 0x1008ff69,
   'OfficeHome' => 0x1008ff6a,
   'Open' => 0x1008ff6b,
   'Option' => 0x1008ff6c,
   'Paste' => 0x1008ff6d,
   'Phone' => 0x1008ff6e,
   'Reply' => 0x1008ff72,
   'Reload' => 0x1008ff73,
   'RotateWindows' => 0x1008ff74,
   'RotationPB' => 0x1008ff75,
   'RotationKB' => 0x1008ff76,
   'Save' => 0x1008ff77,
   'ScrollUp' => 0x1008ff78,
   'ScrollDown' => 0x1008ff79,
   'ScrollClick' => 0x1008ff7a,
   'Send' => 0x1008ff7b,
   'Spell' => 0x1008ff7c,
   'SplitScreen' => 0x1008ff7d,
   'Support' => 0x1008ff7e,
   'TaskPane' => 0x1008ff7f,
   'Terminal' => 0x1008ff80,
   'Tools' => 0x1008ff81,
   'Travel' => 0x1008ff82,
   'UserPB' => 0x1008ff84,
   'User1KB' => 0x1008ff85,
   'User2KB' => 0x1008ff86,
   'Video' => 0x1008ff87,
   'WheelButton' => 0x1008ff88,
   'Word' => 0x1008ff89,
   'Xfer' => 0x1008ff8a,
   'ZoomIn' => 0x1008ff8b,
   'ZoomOut' => 0x1008ff8c,
   'Away' => 0x1008ff8d,
   'Messenger' => 0x1008ff8e,
   'WebCam' => 0x1008ff8f,
   'MailForward' => 0x1008ff90,
   'Pictures' => 0x1008ff91,
   'Music' => 0x1008ff92,
   'Battery' => 0x1008ff93,
   'Bluetooth' => 0x1008ff94,
   'WLAN' => 0x1008ff95,
   'UWB' => 0x1008ff96,
   'AudioForward' => 0x1008ff97,
   'AudioRepeat' => 0x1008ff98,
   'AudioRandomPlay' => 0x1008ff99,
   'Subtitle' => 0x1008ff9a,
   'AudioCycleTrack' => 0x1008ff9b,
   'CycleAngle' => 0x1008ff9c,
   'FrameBack' => 0x1008ff9d,
   'FrameForward' => 0x1008ff9e,
   'Time' => 0x1008ff9f,
   'SelectButton' => 0x1008ffa0,
   'View' => 0x1008ffa1,
   'TopMenu' => 0x1008ffa2,
   'Red' => 0x1008ffa3,
   'Green' => 0x1008ffa4,
   'Yellow' => 0x1008ffa5,
   'Blue' => 0x1008ffa6,
   'Suspend' => 0x1008ffa7,
   'Hibernate' => 0x1008ffa8,
   'TouchpadToggle' => 0x1008ffa9,
   'Switch_VT_1' => 0x1008fe01,
   'Switch_VT_2' => 0x1008fe02,
   'Switch_VT_3' => 0x1008fe03,
   'Switch_VT_4' => 0x1008fe04,
   'Switch_VT_5' => 0x1008fe05,
   'Switch_VT_6' => 0x1008fe06,
   'Switch_VT_7' => 0x1008fe07,
   'Switch_VT_8' => 0x1008fe08,
   'Switch_VT_9' => 0x1008fe09,
   'Switch_VT_10' => 0x1008fe0a,
   'Switch_VT_11' => 0x1008fe0b,
   'Switch_VT_12' => 0x1008fe0c,
   'Ungrab' => 0x1008fe20,
   'ClearGrab' => 0x1008fe21,
   'Next_VMode' => 0x1008fe22,
   'Prev_VMode' => 0x1008fe23,
);
1;

=head1 NAME

Gtk2::Gdk::Keysyms - key codes for Gtk2 programs

=head1 SYNOPSIS

 use Gtk2;
 use Gtk2::Gdk::Keysyms;

 #
 # the most common use is for deciphering keycodes in key events,
 # like this:
 #
 sub key_press_handler {
         my ($widget, $event) = @_;
         if ($event->keyval == $Gtk2::Gdk::Keysyms{Escape}) {
                 abort_whatever ();
                 return 1;
         }
         elsif ($event->keyval == $Gtk2::Gdk::Keysyms{F1}) {
                 do_help_thing ();
                 return 1;
         }
         elsif ($event->keyval == $Gtk2::Gdk::Keysyms{KP_Enter}) {
                 execute_selected_text_as_command ();
                 return 1;
         }
         # we didn't handle it, pass it on...
         return 0;
 }

=head1 DESCRIPTION

Gdk defines symbolic names for the codes associated with each key on a
keyboard, so that you don't go nuts with numeric values in your programs.
The hash C<%Gtk2::Gdk::Keysyms> holds all those keycodes, indexed by the
name, for use in your perl programs when you need to do custom key handling.
This commonly occurs when you want to bind an action to a key that isn't 
usable as an accelerator, or when you don't have accelerators, or if you're
trying to write an easter egg, or whatever.

As the list of keycodes is quite large and rather rarely used in application
code, we've put it in a separately-loaded module to save space.  As an
alternative, you might want to investigate C<Gtk2::Gdk-E<gt>keyval_from_name> which
offers basically the same functionality as the hash.

To get a list of all available keys, either dump C<%Gtk2::Gdk::Keysyms>, or
look at the source of this module with C<perldoc -m Gtk2::Gdk::Keysyms>.

=head1 AUTHOR

This module was automatically generated by a very simple perl script
from gdk/gdkkeysyms.h.  Programs that write programs are the happiest
programs of all.

=head1 COPYRIGHT

Copyright (C) 2003, 2009 by the gtk2-perl team (see the file AUTHORS for the
full list)

This library is free software; you can redistribute it and/or modify it under
the terms of the GNU Library General Public License as published by the Free
Software Foundation; either version 2.1 of the License, or (at your option) any
later version.

This library is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU Library General Public License for more
details.

You should have received a copy of the GNU Library General Public License along
with this library; if not, write to the Free Software Foundation, Inc., 
51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.

=head1 SEE ALSO

L<perl>, L<Gtk2>, L<Gtk2::Gdk>
